Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1401)

Unified Diff: content/public/common/content_client.h

Issue 2582463003: media: Verify CDM Host files (Closed)
Patch Set: Polished! Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/common/content_client.h
diff --git a/content/public/common/content_client.h b/content/public/common/content_client.h
index 1974ba031a4c2a35dc29329790423752c77854fb..b2823b4ad53291ee2c9b2e2bf84a70154eefa15e 100644
--- a/content/public/common/content_client.h
+++ b/content/public/common/content_client.h
@@ -45,6 +45,7 @@ class ContentGpuClient;
class ContentRendererClient;
class ContentUtilityClient;
class OriginTrialPolicy;
+struct CdmHostFilePath;
struct CdmInfo;
struct PepperPluginInfo;
@@ -87,11 +88,16 @@ class CONTENT_EXPORT ContentClient {
virtual void AddPepperPlugins(
std::vector<content::PepperPluginInfo>* plugins) {}
// Gives the embedder a chance to register the content decryption
// modules it supports.
virtual void AddContentDecryptionModules(
std::vector<content::CdmInfo>* cdms) {}
+ // Gives the embedder a chance to register Content Decryption Module (CDM)
+ // host file paths.
+ virtual void AddContentDecryptionModuleHostFilePaths(
+ std::vector<content::CdmHostFilePath>* cdm_host_file_paths) {}
+
// Gives the embedder a chance to register its own schemes early in the
// startup sequence.
// For the secure schemes and origins that need to be considered trustworthy,
@@ -87,11 +88,16 @@ class CONTENT_EXPORT ContentClient {
virtual void AddPepperPlugins(
std::vector<content::PepperPluginInfo>* plugins) {}
- // Gives the embedder a chance to register the content decryption
- // modules it supports.
+ // Gives the embedder a chance to register the Content Decryption
+ // Modules (CDM) it supports.
virtual void AddContentDecryptionModules(
std::vector<content::CdmInfo>* cdms) {}

Powered by Google App Engine
This is Rietveld 408576698